var LaunchyContext = function() {}

LaunchyContext.prototype.init = function() {
	// did Launchy already load?
	var ass = Components.classes["@mozilla.org/appshell/appShellService;1"].getService(Components.interfaces.nsIAppShellService);
	var w = ass.hiddenDOMWindow;
	if (typeof(w.launchy) == "undefined") {
		w.launchy = LaunchyContext;
		var prefService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
		LaunchyContext.pref = prefService.getBranch(null);
		try {
			LaunchyContext.dev = LaunchyContext.pref.getBoolPref("extensions.launchy.developer");
			if (LaunchyContext.dev) {
				launchyShared.trace("Developer information is on - Version 4.1.0");
			}
		} catch(ex) {
		}

		// showfileicons
		try {
			LaunchyContext.showfileicons = LaunchyContext.pref.getBoolPref("extensions.launchy.showfileicons");
			if (LaunchyContext.showfileicons) {
				launchyShared.trace("Show file icons in Launchy menus");
			} else {
				launchyShared.trace("Hide file icons in Launchy menus");
			}
		} catch(ex) {
		}

		// cleanup temporary view files
		launchyContext.doSourceCleanup();

		// auto detect applications
		launchyApps.init();

		// show the first time welcome note
		if (LaunchyContext.pref.getBoolPref("extensions.launchy.firsttime")) {
			launchyShared.trace("Try to show the firsttime note");
			window.setTimeout("launchyContext.firsttime()", 50);
		}

		w.launchy = LaunchyContext;
	} else {
		LaunchyContext = w.launchy;
		launchyShared.trace("Using cached info from hidden DOM window");
		prefService = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
		LaunchyContext.pref = prefService.getBranch(null);
	}
	launchyContext.PrefChangeObserver = {
		observe: function(aSubject, aTopic, aData) {
			launchyContext.prefChanged(aSubject, aTopic, aData);
		}
	};
	try {
		LaunchyContext.pref.addObserver("extensions.launchy", launchyContext.PrefChangeObserver, false);
	} catch(ex) {
		launchyShared.trace("Unable to add addObserver due to:\n" + ex);
	}
}

LaunchyContext.prototype.firsttime = function() {
	if (typeof(BrowserCustomizeToolbar) == "function" || typeof(CustomizeMailToolbar) == "function") {
		var message = launchyContext.getBundle("launchy-firsttime-message");
		var checkbox = launchyContext.getBundle("launchy-firsttime-checkbox");
		var showAgain = {value: false};
		var but = document.getElementById("launchy-toolbar-browser");
		if (!but) {
			var ps = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
			var rv = ps.confirmEx(window, "Launchy", message, (Components.interfaces.nsIPromptService.BUTTON_TITLE_YES * Components.interfaces.nsIPromptService.BUTTON_POS_0) + (Components.interfaces.nsIPromptService.BUTTON_TITLE_NO * Components.interfaces.nsIPromptService.BUTTON_POS_1), null, null, null, checkbox, showAgain);
			if (rv == 0) {
				if (typeof(BrowserCustomizeToolbar) == "function") {
					BrowserCustomizeToolbar();
				} else if (typeof(CustomizeMailToolbar) == "function") {
					CustomizeMailToolbar('mail-toolbox');
				}
			}
		}
		LaunchyContext.pref.setBoolPref("extensions.launchy.firsttime", showAgain.value);
	} else {
		launchyShared.trace("No known CustomizeToolbar function");
	}
}

LaunchyContext.prototype.doContext = function(menuid) {
	var children = menuid.childNodes;
	for (var j = children.length-1; j >= 0; j--) {
		menuid.removeChild(children[j]);
	}

	var label;
	var tooltip;
	var flabel;
	var ftooltip;
	var menuitem;

	if (typeof(LaunchyContext.winhooks) != "undefined" && !LaunchyContext.winhooks && typeof(LaunchyContext.apps) == "undefined") {
		launchyShared.trace("No winhooks");
		label = launchyContext.getBundle("launchy-disable-nowinhooks-label");
		tooltip = launchyContext.getBundle("launchy-disable-nowinhooks-tooltip");
		menuitem = document.createElement("menuitem");
		menuitem.setAttribute("label", label);
		menuitem.setAttribute("tooltiptext", tooltip);
		menuitem.setAttribute("oncommand", "launchyShared.help(\"nowinhooks\");");
		menuid.appendChild(menuitem);
		return;
	} else if (typeof(LaunchyContext.apps) == "undefined" || !LaunchyContext.apps.length) {
		launchyShared.trace("No apps");
		label = launchyContext.getBundle("launchy-disable-noapps-label");
		tooltip = launchyContext.getBundle("launchy-disable-noapps-tooltip");
		menuitem = document.createElement("menuitem");
		menuitem.setAttribute("label", label);
		menuitem.setAttribute("tooltiptext", tooltip);
		menuitem.setAttribute("oncommand", "launchyShared.help(\"noapps\");");
		menuid.appendChild(menuitem);
		return;
	}

	var num = 0;
	var sepfound = false;
	// right click on page or click on toolbar
	if (!gContextMenu || !gContextMenu.onLink && !gContextMenu.onMailtoLink && !gContextMenu.onImage) {
		launchyShared.trace("Right click on page or click on toolbar");
		label = launchyContext.getBundle("launchy-page-label");
		tooltip = launchyContext.getBundle("launchy-page-tooltip");
		if (gContextMenu && gContextMenu.inFrame) {
			flabel = launchyContext.getBundle("launchy-page-frame-label");
			ftooltip = launchyContext.getBundle("launchy-page-frame-tooltip");
		}
		for (var i = 0; LaunchyContext.apps.length > i; i++) {
			if (LaunchyContext.apps[i].type == 1) {
				menuitem = document.createElement("menuitem");
				menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\");");
				launchyContext.addIcon(menuitem, i);
				menuid.appendChild(menuitem);
				num++;
				if (gContextMenu && gContextMenu.inFrame) {
					menuitem = document.createElement("menuitem");
					menuitem.setAttribute("label", launchyShared.replaceInsert(flabel, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(ftooltip, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\", 0, 1);");
					launchyContext.addIcon(menuitem, i);
					menuid.appendChild(menuitem);
				}
			}
		}
		label = launchyContext.getBundle("launchy-source-label");
		tooltip = launchyContext.getBundle("launchy-source-tooltip");
		if (gContextMenu && gContextMenu.inFrame) {
			flabel = launchyContext.getBundle("launchy-source-frame-label");
			ftooltip = launchyContext.getBundle("launchy-source-frame-tooltip");
		}
		for (i = 0; LaunchyContext.apps.length > i; i++) {
			if (LaunchyContext.apps[i].type == 7) {
				if (sepfound == false && menuid.lastChild && menuid.lastChild.localName != "menuseparator") {
					menuitem = document.createElement("menuseparator");
					menuid.appendChild(menuitem);
					sepfound = true;
				}
				menuitem = document.createElement("menuitem");
				menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("oncommand", "launchyContext.doSource(\"" + i + "\", 0, 0);");
				launchyContext.addIcon(menuitem, i);
				menuid.appendChild(menuitem);
				num++;
				if (gContextMenu && gContextMenu.inFrame) {
					menuitem = document.createElement("menuitem");
					menuitem.setAttribute("label", launchyShared.replaceInsert(flabel, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(ftooltip, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("oncommand", "launchyContext.doSource(\"" + i + "\", 0, 1);");
					launchyContext.addIcon(menuitem, i);
					menuid.appendChild(menuitem);
				}
			}
		}
	}

	// right click on link
	else if (gContextMenu.onLink && gContextMenu.onSaveableLink && !gContextMenu.onMailtoLink) {
		launchyShared.trace("Right click on link");
		label = launchyContext.getBundle("launchy-link-label");
		tooltip = launchyContext.getBundle("launchy-link-tooltip");
		for (i = 0; LaunchyContext.apps.length > i; i++) {
			if (LaunchyContext.apps[i].type == 1) {
				menuitem = document.createElement("menuitem");
				menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\", 1);");
				launchyContext.addIcon(menuitem, i);
				menuid.appendChild(menuitem);
				num++;
			}
		}
		for (i = 0; LaunchyContext.apps.length > i; i++) {
			if (LaunchyContext.apps[i].type == 3) {
				if (sepfound == false && menuid.lastChild && menuid.lastChild.localName != "menuseparator") {
					menuitem = document.createElement("menuseparator");
					menuid.appendChild(menuitem);
					sepfound = true;
				}
				menuitem = document.createElement("menuitem");
				menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\", 1);");
				launchyContext.addIcon(menuitem, i);
				menuid.appendChild(menuitem);
				num++;
			}
		}
		sepfound = false;
		var url = gContextMenu.link.toString();
		launchyShared.trace("Clicked on url <" + url + ">");
		var re=/^(http:\/\/ftp|ftp:\/\/)/i;
		if (url.match(re)) {
			url = url.replace(/^http:\/\//i, "ftp:\/\/");
			LaunchyContext.url = url;
			label = launchyContext.getBundle("launchy-ftp-label");
			tooltip = launchyContext.getBundle("launchy-ftp-tooltip");
			sepfound = false;
			for (i = 0; LaunchyContext.apps.length > i; i++) {
				if (LaunchyContext.apps[i].type == 4) {
					if (sepfound == false && menuid.lastChild && menuid.lastChild.localName != "menuseparator") {
						menuitem = document.createElement("menuseparator");
						menuid.appendChild(menuitem);
						sepfound = true;
					}
					menuitem = document.createElement("menuitem");
					menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\", 1);");
					launchyContext.addIcon(menuitem, i);
					menuid.appendChild(menuitem);
					num++;
				}
			}
		}
		label = launchyContext.getBundle("launchy-download-label");
		tooltip = launchyContext.getBundle("launchy-download-tooltip");
		sepfound = false;
		for (i = 0; LaunchyContext.apps.length > i; i++) {
			if (LaunchyContext.apps[i].type == 5) {
				if (sepfound == false && menuid.lastChild && menuid.lastChild.localName != "menuseparator") {
					menuitem = document.createElement("menuseparator");
					menuid.appendChild(menuitem);
					sepfound = true;
				}
				menuitem = document.createElement("menuitem");
				menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\", 1);");
				launchyContext.addIcon(menuitem, i);
				menuid.appendChild(menuitem);
				num++;
			}
		}
		if (launchyShared.isLinkType("file", url)) {
			if (/file:\/\/\//.test(url)) {
			} else {
				url = url.replace(/(\w+:\/\/)/, "\\\\");
				launchyShared.trace("Mangled URL <" + url + ">");
				url = url.replace(/(\/)/g, "\\");
				launchyShared.trace("Mangled URL <" + url + ">");
				url = url.replace(/(\+)/g, " ");
				launchyShared.trace("Mangled URL <" + url + ">");
			}
			url = unescape(url);
			launchyShared.trace("Mangled URL <" + url + ">");
			LaunchyContext.url = url;

			label = launchyContext.getBundle("launchy-file-label");
			tooltip = launchyContext.getBundle("launchy-file-tooltip");
			sepfound = false;
			for (i = 0; LaunchyContext.apps.length > i; i++) {
				if (LaunchyContext.apps[i].type == 6) {
					if (sepfound == false && menuid.lastChild && menuid.lastChild.localName != "menuseparator") {
						menuitem = document.createElement("menuseparator");
						menuid.appendChild(menuitem);
						sepfound = true;
					}
					menuitem = document.createElement("menuitem");
					menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
					menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\", 1);");
					launchyContext.addIcon(menuitem, i);
					menuid.appendChild(menuitem);
					num++;
				}
			}
		}
	}

	// right click on mailto link
	else if (gContextMenu.onMailtoLink) {
		launchyShared.trace("Right click on mailto link");
		label = launchyContext.getBundle("launchy-mail-label");
		tooltip = launchyContext.getBundle("launchy-mail-tooltip");
		sepfound = false;
		for (i = 0; LaunchyContext.apps.length > i; i++) {
			if (LaunchyContext.apps[i].type == 2) {
				menuitem = document.createElement("menuitem");
				menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("oncommand", "launchyContext.doApp(\"" + i + "\", 1);");
				launchyContext.addIcon(menuitem, i);
				menuid.appendChild(menuitem);
				num++;
			}
		}
	}

	// right click on image
	if ((gContextMenu && (gContextMenu.onImage || gContextMenu.onStandaloneImage || gContextMenu.hasBGImage)) || window.content.document.contentType.substr(0,6) == "image/") {
		launchyShared.trace("Right click on image");
		label = launchyContext.getBundle("launchy-image-label");
		tooltip = launchyContext.getBundle("launchy-image-tooltip");
		sepfound = false;
		if (sepfound == false && menuid.lastChild && menuid.lastChild.localName != "menuseparator") {
			menuitem = document.createElement("menuseparator");
			menuid.appendChild(menuitem);
			sepfound = true;
		}
		for (i = 0; LaunchyContext.apps.length > i; i++) {
			if (LaunchyContext.apps[i].type == 8) {
				menuitem = document.createElement("menuitem");
				menuitem.setAttribute("label", launchyShared.replaceInsert(label, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("tooltiptext", launchyShared.replaceInsert(tooltip, 1, LaunchyContext.apps[i].name));
				menuitem.setAttribute("oncommand", "launchyContext.doSource(\"" + i + "\", 0, 0, 1);");
				launchyContext.addIcon(menuitem, i);
				menuid.appendChild(menuitem);
				num++;
			}
		}
	}

	// add options but only on the toolbar
	if (!gContextMenu) {
		launchyShared.trace("Add option");
		if (menuid.lastChild && menuid.lastChild.localName != "menuseparator") {
			menuitem = document.createElement("menuseparator");
			menuid.appendChild(menuitem);
		}
		menuitem = document.createElement("menuitem");
		menuitem.setAttribute("label", launchyContext.getBundle("launchy-options-label"));
		menuitem.setAttribute("tooltiptext", launchyContext.getBundle("launchy-options-tooltip"));
		menuitem.setAttribute("oncommand", "openDialog('chrome://launchy/content/options.xul', '', 'chrome,modal');");
		if (typeof(LaunchyContext.showfileicons) != "undefined" && LaunchyContext.showfileicons) {
			menuitem.setAttribute("id", "launchy-options-toolbar");
		}
		menuid.appendChild(menuitem);
	}

	// no action
	if (!num) {
		label = launchyContext.getBundle("launchy-disable-noaction-label");
		tooltip = launchyContext.getBundle("launchy-disable-noaction-tooltip");
		menuitem = document.createElement("menuitem");
		menuitem.setAttribute("label", label);
		menuitem.setAttribute("tooltiptext", tooltip);
		menuitem.setAttribute("oncommand", "launchyShared.help(\"noaction\");");
		menuid.appendChild(menuitem);
		return;
	}
}

LaunchyContext.prototype.doApp = function(app_entry, on_link, on_frame) {
	var app_exe = LaunchyContext.apps[app_entry].exe;

	var url;
	if (typeof(LaunchyContext.url) != "undefined" && LaunchyContext.url) {
		launchyShared.trace("url");
		url = LaunchyContext.url;
		LaunchyContext.url = "";
	} else {
		if (on_link) {
			launchyShared.trace("on_link");
			url = gContextMenu.link;
		} else {
			if (on_frame) {
				launchyShared.trace("on_frame");
				url = window.content.location;
			} else {
				url = top.window.content.location;
			}
		}
	}

	if (!url) {
		launchyShared.trace("Didn't get an URL");
		return;
	} else {
		launchyShared.trace("Got URL <" + url + ">");
		if (launchyShared.isLinkType("file", url)) {
			url = Launchy_FileIO.urlToPath(url);
			launchyShared.trace("URL converted into <" + url + ">");
		}
	}

	var args = launchyContext.getArgs(LaunchyContext.apps[app_entry], url);

	launchyShared.trace("About to run:\n" + app_exe + " " + args);
	launchyContext.updateStatusbar("Running <" + app_exe + " " + args.join(" ") + ">");

	Launchy_FileIO.run(app_exe, args);
}

LaunchyContext.prototype.doSource = function(app_entry, on_link, on_frame, on_image) {
	var app_exe = LaunchyContext.apps[app_entry].exe;

	var url;
	if (on_frame) {
		launchyShared.trace("on_frame");
		url = window.content.location;
	} else if (on_link) {
		launchyShared.trace("on_link");
		url = (gContextMenu ? gContextMenu.link : window.content.document);
	} else if (on_image) {
		launchyShared.trace("on_image");
		url = (gContextMenu ? (gContextMenu.imageURL ? gContextMenu.imageURL : gContextMenu.bgImageURL) : window.content.document);
	} else {
		launchyShared.trace("plain");
		url = top.window.content.location;
	}

	var tmpfile;
	if (url) {
		launchyShared.trace("URL <" + url + ">");
		if (launchyShared.isLinkType("file", url)) {
			url = url.toString().replace(/[?#].*$/, "");
			launchyShared.trace("URL local <" + url + ">");
			tmpfile = Launchy_FileIO.urlToPath(url);
			launchyShared.trace("Temporary file <" + tmpfile + ">");

		} else {
			var d = new Date().getTime();

			var fe = "html";
			var URLfe = Components.classes["@mozilla.org/network/standard-url;1"].createInstance(Components.interfaces.nsIURL);
			URLfe.spec = url;
			try {
				if (URLfe.fileExtension) {
					fe = URLfe.fileExtension;
				}
			} catch (ex) {
			}

			var ft = Launchy_DirIO.get("TmpD");
			ft.append("launchy-view-" + d + "." + fe);
			tmpfile = ft.path;

			launchyShared.trace("Temporary file <" + tmpfile + ">");

			var f = Components.classes["@mozilla.org/file/local;1"].createInstance(Components.interfaces.nsILocalFile);
			f.initWithPath(tmpfile);

			const nsIWBP = Components.interfaces.nsIWebBrowserPersist;
			var persist = Components.classes["@mozilla.org/embedding/browser/nsWebBrowserPersist;1"].createInstance(nsIWBP);
			persist.persistFlags = nsIWBP.PERSIST_FLAGS_FROM_CACHE | nsIWBP.PERSIST_FLAGS_REPLACE_EXISTING_FILES | nsIWBP.PERSIST_FLAGS_DONT_CHANGE_FILENAMES;

			var URI = Components.classes["@mozilla.org/network/standard-url;1"].createInstance(Components.interfaces.nsIURI);
			URI.spec = url;

			launchyShared.trace("Trying to save URL <" + url + ">");
			try {
				persist.saveURI(URI, null, null, null, null, f);
			} catch (ex) {
				launchyShared.trace("Cannot save URL <" + url + "> due to:\n" + ex);
			}
		}

		var args = launchyContext.getArgs(LaunchyContext.apps[app_entry], tmpfile);

		launchyShared.trace("About to run:\n" + app_exe + " " + args);
		launchyContext.updateStatusbar("Running <" + app_exe + " " + args.join(" ") + ">");

		Launchy_FileIO.run(app_exe, args);
	} else {
		launchyShared.trace("Unable to get URL");
	}
}

LaunchyContext.prototype.addIcon = function(menuitem, i) {
	if (typeof(LaunchyContext.showfileicons) != "undefined" && LaunchyContext.showfileicons) {
		menuitem.setAttribute("class", "menuitem-iconic");
		if (LaunchyContext.apps[i].icon) {
			menuitem.setAttribute("image", "moz-icon:file://" + LaunchyContext.apps[i].icon + "?size=16");
		} else {
			menuitem.setAttribute("image", "moz-icon:file://" + LaunchyContext.apps[i].exe + "?size=16");
		}
	}
}

LaunchyContext.prototype.getArgs = function(app_entry, url) {
	var xargs = new Array();
	if (app_entry.args && typeof(app_entry.args) == "object") {
		xargs = app_entry.args.join(',').split(',');
		var u = false;
		for (var i=0; i < xargs.length; i++) {
			var tmp = launchyShared.replaceInsert(xargs[i], 1, url);
			if (tmp != xargs[i]) {
				xargs[i] = tmp;
				u = true;
			}
		}
		if (!u) {
			xargs[xargs.length] = url;
		}
	} else if (app_entry.args && typeof(app_entry.args) == "string") {
		tmp = launchyShared.replaceInsert(app_entry.args, 1, url);
		if (tmp != app_entry.args) {
			xargs = tmp.split(" ");
		} else {
			xargs = app_entry.args.split(" ");
			xargs[xargs.length] = url;
		}
	} else {
		xargs[xargs.length] = url;
	}
	return xargs;
}

LaunchyContext.prototype.updateStatusbar = function(txt) {
	var stat = document.getElementById("statusbar-display") || document.getElementById("statusText");
	if (stat)
		stat.label = txt;
}

LaunchyContext.prototype.getBundle = function(s, i) {
	var b;
	var d = (i ? i : "bundle_launchy");
	try {
		b = document.getElementById(d).getString(s);
	} catch(ex) {
		launchyShared.trace("Unable to get bundle <" + s + "> from <" + d + "> due to:\n" + ex);
	}
	if (!b)
		launchyShared.trace("Unable to get bundle <" + s + "> from <" + d + ">");
	return b;
}

LaunchyContext.prototype.doSourceCleanup = function() {
	var u = new Date().getTime();
	var tmpdir = Launchy_DirIO.get("TmpD");
	var dir = Launchy_DirIO.open(tmpdir.path);
	var contents = Launchy_DirIO.read(dir, true);
	launchyShared.trace("Number of temp files in <" + tmpdir.path + "> is <" + contents.length + ">");
	if (contents.length < 1000) {
		var re=/^launchy-view-(\d+)\..*?$/i;
		for (var i = 0; i < contents.length; i++) {
			if (contents[i].isFile()) {
				var x = contents[i].leafName.match(re);
				if (x && x[1]) {
					// delete temp files older than one day
					if (u - parseInt(x[1]) > 60*60*24*1000) {
						launchyShared.trace("Deleting old view files <" + contents[i].leafName + ">");
						contents[i].remove(false);
					}
				}
			}
		}
		var ua = new Date().getTime();
		launchyShared.trace("Deleting files took : <" + (ua-u) + "> ms");
	} else {
		launchyShared.trace("Cleanup was skipped due to high number of temp files");
	}
}

LaunchyContext.prototype.prefChanged = function(aSubject, aTopic, aData) {
	launchyShared.trace("Pref changed: <" + aData + ">");
	try {
		var pref = LaunchyContext.pref.getBoolPref(aData);
		launchyShared.trace("getpref: " + pref);
	} catch(ex) {
		launchyShared.trace("ex: " + ex);
		pref = false;
		launchyShared.trace("defaultpref: " + pref);
	}
	launchyShared.trace("pref: " + pref);
	switch (aData) {
		case "extensions.launchy.autodetectapps":
			launchyShared.trace("ok: extensions.launchy.autodetectapps");
			break;
		case "extensions.launchy.showfileicons":
			launchyShared.trace("ok: extensions.launchy.showfileicons");
			LaunchyContext.showfileicons = pref;
			break;
		case "extensions.launchy.developer":
			launchyShared.trace("ok: extensions.launchy.developer");
			LaunchyContext.developer = pref;
			break;
		case "extensions.launchy.xmlfile":
			launchyShared.trace("xmlfile will be loaded the next time Launchy is loaded");
			break;
		default:
			launchyShared.trace("NOT ok: " + aData);
			break;
	}
}

// create the object
const launchyContext = new LaunchyContext();
window.addEventListener("load", launchyContext.init, false);
